class ConferencesController < ApplicationController
  def index
    @conferences = Conference.all
  end

  def show
    @conference = Conference.find_by(slug: params[:slug])
    @sessions = @conference.sessions.where.not(starts_at: nil).includes(:stage, :assignments).where(stage: @conference.relevant_stages).order(:starts_at)
    if params[:date]
      date = Time.parse(params[:date])
      logger.debug(date)
      @sessions = @sessions.where(starts_at: date.beginning_of_day..date.end_of_day)
    end
    @users = User.all
  end

  def edit
  end

  def update
  end

  def stats
    @conference = Conference.find_by(slug: params[:slug])
    @relevant_stages = @conference.relevant_stages
    @relevant_sessions = @conference.sessions.includes(:stage, :assignments, :speakers, assignments: :user).where(stage: @conference.relevant_stages).order(:starts_at)
    @assignees = @relevant_sessions.map(&:assignments).flatten.map(&:user).uniq
    @language_stats = @relevant_sessions.group_by { |s| s.language }.transform_values(&:count)
    @speakers = @relevant_sessions.map(&:speakers)
    @unique_speakers = @speakers.flatten.uniq.count
    @speakers_per_session = @speakers.map(&:count).sum.to_f / @speakers.size.to_f
    @day_stats = @relevant_sessions.group_by { |s| s.starts_at.to_date }.transform_values do |se|
      {
        starts_at: se.first.starts_at,
        ends_at: se.last.ends_at,
        sessions_count: se.count,
        wall_clock_time_min: (se.last.ends_at - se.first.starts_at) / 60.0,
        scheduled_time_min: se.map { |x| (x.ends_at - x.starts_at) / 60.0 }.sum
      }
    end
    @total_stats = @day_stats.values.inject { |m, x| m.merge(x) { |k, o, n| o + n } }.slice(:sessions_count, :wall_clock_time_min, :scheduled_time_min)
  end
end
